==> vite-plugin-vue-component-preview-1.0.0.tgz: package/client/index.js <==
import { computed, defineAsyncComponent, h, ref, Suspense } from 'vue';
export default function (app) {
    const location = globalThis.location;
    if (location && location.pathname.startsWith('/__preview/')) {
        app._component.setup = () => {
            const pathname = ref(location.pathname);
            const importPath = computed(() => pathname.value.substring('/__preview'.length));
            const Component = computed(() => {
                const _fileName = importPath.value;
                return defineAsyncComponent(() => import(/* @vite-ignore */ _fileName));
            });
            const Layout = computed(() => {
                const _fileName = importPath.value;
                return defineAsyncComponent(() => import(/* @vite-ignore */ _fileName + '__preview.vue'));
            });
            if (import.meta.hot) {
                try {
                    import.meta.hot.send('vue-component-preview:hash', {
                        file: importPath.value,
                        text: location.hash ? atob(location.hash.substring(1)) : '',
                    });
                }
                catch (_a) { }
                window.addEventListener('hashchange', () => {
                    try {
                        import.meta.hot.send('vue-component-preview:hash', {
                            file: importPath.value,
                            text: location.hash ? atob(location.hash.substring(1)) : '',
                        });
                    }
                    catch (_a) { }
                });
            }
            return () => h(Suspense, undefined, [
                h(Layout.value, undefined, {
                    default: (props) => h(Component.value, props)
                })
            ]);
        };
    }
}

==> vite-plugin-vue-component-preview-1.0.2.tgz: package/client/index.js <==
import { computed, defineAsyncComponent, h, ref, Suspense } from 'vue';
export default function (app) {
    const location = globalThis.location;
    if (location && location.pathname.startsWith('/__preview/')) {
        app._component.setup = () => {
            const pathname = ref(location.pathname);
            const importPath = computed(() => pathname.value.substring('/__preview'.length));
            const Component = computed(() => {
                const _fileName = importPath.value;
                return defineAsyncComponent(() => import(/* @vite-ignore */ _fileName));
            });
            const Layout = computed(() => {
                const _fileName = importPath.value;
                return defineAsyncComponent(() => import(/* @vite-ignore */ _fileName + '__preview.vue'));
            });
            if (import.meta.hot) {
                fireHash();
                window.addEventListener('hashchange', fireHash);
            }
            return () => h(Suspense, undefined, [
                h(Layout.value, undefined, {
                    default: (props) => h(Component.value, props)
                })
            ]);
            function fireHash() {
                var _a;
                try {
                    (_a = import.meta.hot) === null || _a === void 0 ? void 0 : _a.send('vue-component-preview:hash', {
                        file: importPath.value,
                        text: location.hash ? atob(location.hash.substring(1)) : '',
                    });
                }
                catch (_b) { }
            }
        };
    }
}
